module ProjectExample (
	input  wire [4:0]   okUH,
	output wire [2:0]   okHU,
	inout  wire [31:0]  okUHU,
	inout  wire         okAA,

	input  wire         sys_clk_p,
	input  wire         sys_clk_n,
	
	output reg			  SDIN,
	output 				  clk16,
	output reg			  dlatch
	);

// Target interface bus:
wire         okClk;
wire [112:0] okHE;
wire [64:0]  okEH;
wire         sys_clk;

integer 		 var1, counter;
wire			 new_clk;

assign new_clk = clk16;

alt_inbuf_diff sys_clk_io(.i(sys_clk_p), .ibar(sys_clk_n), .o(sys_clk));

// Endpoint connections:
wire [23:0]  ep00wire;	// SPI input
wire			 ep01wire; 	// button
wire			 ep02wire;  // reset

// Modified Clock to approximately ~6.25MHz
wire clk2, clk4, clk8;	// System clock divided by the respective number
wire x1, x2, x3, x4;				// routed wires
parts DFF_div2(sys_clk, ep02wire, x1, clk2, x1);
parts DFF_div4(x1, ep02wire, x2, clk4, x2);
parts DFF_div8(x2, ep02wire, x3, clk8, x3);
parts DFF_div16(x3, ep02wire, x4, clk16, x4);

// Outputs SDIN from MSB to LSB every posedge clock
always @(posedge new_clk)
begin
	if (ep01wire) begin
		counter = 24;
	end
	else if (ep02wire) begin
		counter = 0;
		dlatch = 1'b1;
		SDIN = 1'b0;
	end
	else if (counter <= 24 && counter >= 1 && ep01wire == 0) begin
		dlatch = 1'b0;
		SDIN = ep00wire[counter-1];
		counter = counter - 1;
	end
	else begin
		counter = 0;
		dlatch = 1'b1;
		SDIN = 1'b0;
	end
end
		

// Instantiate the okHost and connect endpoints.
okHost okHI(
	.okUH(okUH),
	.okHU(okHU),
	.okUHU(okUHU),
	.okAA(okAA),
	.okClk(okClk),
	.okHE(okHE), 
	.okEH(okEH)
);

// Your FrontPanel module instantiations here
okWireIn     wi00(.okHE(okHE),                             .ep_addr(8'h00), .ep_dataout(ep00wire)); //digit entry
okWireIn     wi01(.okHE(okHE),                             .ep_addr(8'h01), .ep_dataout(ep01wire)); //button
okWireIn     wi02(.okHE(okHE),                             .ep_addr(8'h02), .ep_dataout(ep02wire)); //reset

endmodule 

module parts (
	input sys_clk,
	input reset,
	input D,
	
	output reg Q, 
	output Qbar
	);

// DFF
assign Qbar = ~Q;
always @(posedge sys_clk) 
begin
	if (reset) begin
		Q <= 1'b0;
	end
	else begin
		Q <= D;
	end
end
endmodule 